require "class"

local gui = require "quickie"

class "Demo" {
    encode = {
        slider = function(x) return x end,
        checkbox = function(x) if x then return 1 else return 0 end end,
    }
}

function Demo:__init__(effect, title, ...)
    self.effect = effect
    self.title = title
    self.variables = {...}

    self.effect:send("width",  love.graphics.getWidth())
    self.effect:send("height", love.graphics.getHeight())
end

function Demo:update(dt)
    local slider = false

    gui.group{grow = "down", pos = {10, 5}, function()
        gui.Label{text = self.title, size = {70}}

        for i, variable in ipairs(self.variables) do
            gui.group{grow = "right", spacing = 5, function()
                if variable.type == "slider" then
                    slider = slider or gui.Slider{info = variable}
                    gui.Label{text = variable.name, size = {70}}
                elseif variable.type == "checkbox" then
                    if gui.Checkbox{checked = variable.value, text = variable.name} then
                        variable.value = not variable.value
                    end
                end
            end}
        end
    end}

    for i, variable in ipairs(self.variables) do
        self.effect:send(variable.name, self.encode[variable.type](variable.value))
    end
end

return Demo
